@@ -1,8 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from pathlib import Path
 from datetime import datetime, timezone, timedelta
+from pathlib import Path
+import warnings
 import covid19dh
 from dask import dataframe as dd
 import pandas as pd
@@ -72,7 +73,7 @@ class DataLoader(Term):
         self._covid19dh_basename = "covid19dh.csv"
         self._covid19dh_citation_secondary = '(Secondary source)' \
             ' Guidotti, E., Ardia, D., (2020), "COVID-19 Data Hub",' \
-            ' Working paper, doi: 10.13140/RG.2.2.11649.81763.' \
+            ' Journal of Open Source Software 5(51):2376, doi: 10.21105/joss.02376.' \
             '\nWe can get Citation list of primary sources with DataLoader(...).covid19dh_citation'
         # JHU dataset: the number of cases
         self.jhu_url = "https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master" \
@@ -527,13 +528,23 @@ class DataLoader(Term):
             (tuple):
                 (pandas.DataFrame): dataset at country level
                 (pandas.DataFrame): dataset at province level
+
+        Notes:
+            For some countries, province-level data is included.
         """
-        c_df = covid19dh.covid19(country=None, level=1, verbose=False)
-        c_citations = covid19dh.cite(c_df)
-        # For some countries, province-level data is included
-        p_df = covid19dh.covid19(country=None, level=2, verbose=False)
-        p_citations = covid19dh.cite(p_df)
+        warnings.simplefilter("ignore", ResourceWarning)
+        c_res = covid19dh.covid19(
+            country=None, level=1, verbose=False, raw=False)
+        p_res = covid19dh.covid19(
+            country=None, level=2, verbose=False, raw=False)
+        try:
+            c_df, c_cite = c_res
+            p_df, p_cite = p_res
+        except ValueError:
+            # covid19dh <= 1.14
+            c_df, c_cite = c_res.copy(), covid19dh.cite(c_res)
+            p_df, p_cite = p_res.copy(), covid19dh.cite(p_res)
         # Citation
-        citations = list(dict.fromkeys(c_citations + p_citations))
+        citations = list(dict.fromkeys(c_cite + p_cite))
         self._covid19dh_citation = "\n".join(citations)
         return (c_df, p_df)
