@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 from datetime import datetime
+from dask import dataframe as dd
 import numpy as np
 import pandas as pd
 from covsirphy.util.error import deprecate
@@ -20,9 +21,17 @@ class PopulationData(CleaningBase):
         CleaningBase.N
     ]
 
-    def __init__(self, filename):
+    def __init__(self, filename=None):
         self.created_time = datetime.now()
-        super().__init__(filename)
+        if filename is None:
+            self._raw = pd.DataFrame()
+            self._cleaned_df = pd.DataFrame(columns=self.POPULATION_COLS)
+        else:
+            self._raw = dd.read_csv(
+                filename, dtype={"Province/State": "object"}
+            ).compute()
+            self._cleaned_df = self._cleaning()
+        self._citation = str()
 
     def _cleaning(self):
         """
@@ -58,8 +67,7 @@ class PopulationData(CleaningBase):
         ]
         self.ensure_dataframe(df, name="the raw data", columns=expected_cols)
         # ISO3
-        if self.ISO3 not in df.columns:
-            df[self.ISO3] = self.UNKNOWN
+        df[self.ISO3] = df[self.ISO3] if self.ISO3 in df.columns else self.UNKNOWN
         # Date
         if self.DATE in df.columns:
             df[self.DATE] = pd.to_datetime(df[self.DATE])
@@ -149,8 +157,7 @@ class PopulationData(CleaningBase):
             df["key"] = df[self.COUNTRY].str.cat(
                 df[self.PROVINCE], sep=self.SEP
             )
-        pop_dict = df.set_index("key").to_dict()[self.N]
-        return pop_dict
+        return df.set_index("key").to_dict()[self.N]
 
     def value(self, country, province=None, date=None):
         """
