@@ -5,29 +5,27 @@ from datetime import datetime, timedelta
 import numpy as np
 import pandas as pd
 from scipy.integrate import solve_ivp
+from covsirphy.util.error import deprecate
 from covsirphy.cleaning.term import Term
 from covsirphy.ode.mbase import ModelBase
 
 
 class ODESimulator(Term):
     """
-    Simulation of an ODE model.
+    Simulation of an ODE model for one phase.
 
     Args:
-        country (str): country name
-        province (str): province name
+        country (str or None): country name
+        province (str or None): province name
     """
 
-    def __init__(self, country, province="-"):
-        self.country = country
-        self.province = province
-        # list of dictionary
+    def __init__(self, country=None, province=None):
+        self.country = country or self.UNKNOWN
+        self.province = province or self.UNKNOWN
         # keys: model, step_n, population, param_dict, y0_dict
-        self.settings = list()
-        # tau-free data: reset index, 't', columns with dimensional variables
-        self._taufree_df = pd.DataFrame()
+        self.setting = {}
         # key: non-dim variable name, value: dimensional variable name
-        self.var_dict = dict()
+        self.var_dict = {}
 
     def add(self, model, step_n, population, param_dict=None, y0_dict=None):
         """
@@ -51,38 +49,47 @@ class ODESimulator(Term):
                 - None or if not include some variables, the last values will be used
                     - NameError when the model is the first model
                     - NameError if new variable are included
-
-        Returns:
-            self
         """
-        # Validate the arguments
-        model = self.ensure_subclass(model, ModelBase, name="model")
-        step_n = self.ensure_natural_int(step_n, name="step_n")
-        population = self.ensure_natural_int(population, name="population")
-        # Check param values
-        param_dict = param_dict or dict()
-        for param in model.PARAMETERS:
-            if param in param_dict.keys():
-                continue
-            if (not self.settings) or (param not in self.settings[-1]["model"].PARAMETERS):
-                s = f"{param} value must be specified in @param_dict."
-                raise NameError(s)
-            param_dict[param] = self.settings[-1]["param_dict"][param]
-        # Check initial values
-        y0_dict = self._ensure_initial_values(model, y0_dict)
+        if self.setting:
+            raise ValueError(
+                "Simulation for two phases is not supported from version 2.7.0")
         # Register the setting
-        self.settings.append(
-            {
-                "model": model,
-                "step_n": step_n,
-                "population": population,
-                "param_dict": param_dict.copy(),
-                "y0_dict": y0_dict.copy(),
-            }
-        )
+        self.setting = {
+            "model": self.ensure_subclass(model, ModelBase, name="model"),
+            "step_n": self.ensure_natural_int(step_n, name="step_n"),
+            "population": self.ensure_population(population),
+            "param_dict": self._ensure_parameters(model, param_dict),
+            "y0_dict": self._ensure_initial_values(model, y0_dict),
+        }
         # Update variable dictionary
         self.var_dict.update(model.VAR_DICT)
-        return self
+
+    def _ensure_parameters(self, model, param_dict):
+        """
+        Validate the dictionary of parameters.
+
+        Args:
+            model (subclass of cs.ModelBase): the ODE model
+            param_dict (dict):
+                - key (str): parameter name
+                - value (float): parameter value
+
+        Returns:
+            dict(str, str): dictionary of parameters
+
+        Notes:
+            If a parameter value is not registered, None will be registered.
+        """
+        param_dict = param_dict or {}
+        usable_dict = {
+            p: param_dict[p] if p in param_dict else None for p in model.PARAMETERS}
+        if None not in usable_dict.values():
+            return usable_dict
+        none_params = [k for (k, v) in usable_dict.items() if v is None]
+        s = "s" if len(none_params) > 1 else ""
+        raise NameError(
+            f"Parameter value{s} of {', '.join(none_params)} must be specified by @param_dict."
+        )
 
     def _ensure_initial_values(self, model, y0_dict):
         """
@@ -94,22 +101,22 @@ class ODESimulator(Term):
                 - key (str): dimensional variable name
                 - value (int):initial value of the variable
 
-        Raises:
-            NameError: [description]
-
         Returns:
-            [type]: [description]
+            dict(str, str): dictionary of initial values
+
+        Notes:
+            If initial value of a variable is not registered, None will be registered.
         """
-        y0_dict = y0_dict or dict()
-        for var in model.VARIABLES:
-            if var in y0_dict.keys():
-                continue
-            if (not self.settings) or (var not in self.settings[-1]["model"].VARIABLES):
-                s = f"Initial value of {var} must be specified in @y0_dict."
-                raise NameError(s)
-            # Will use the last values of the last phase
-            y0_dict[var] = None
-        return y0_dict
+        y0_dict = y0_dict or {}
+        usable_dict = {
+            v: y0_dict[v] if v in y0_dict else None for v in model.VARIABLES}
+        if None not in usable_dict.values():
+            return usable_dict
+        none_vars = [k for (k, v) in usable_dict.items() if v is None]
+        s = "s" if len(none_vars) > 1 else ""
+        raise NameError(
+            f"Initial value{s} of {', '.join(none_vars)} must be specified by @y0_dict."
+        )
 
     def _solve_ode(self, model, step_n, param_dict, y0_dict, population):
         """
@@ -134,9 +141,6 @@ class ODESimulator(Term):
                     - t (int): Elapsed time divided by tau value [-]
                     - columns with dimensional variables
         """
-        step_n = self.ensure_natural_int(step_n, name="step_n")
-        population = self.ensure_natural_int(population, name="population")
-        model = self.ensure_subclass(model, ModelBase, name="model")
         tstart, dt, tend = 0, 1, step_n
         variables = model.VARIABLES[:]
         initials = [y0_dict[var] for var in variables]
@@ -150,39 +154,17 @@ class ODESimulator(Term):
         t_df = pd.Series(data=sol["t"], name=self.TS)
         y_df = pd.DataFrame(data=sol["y"].T.copy(), columns=variables)
         y_df = y_df.round()
-        sim_df = pd.concat([t_df, y_df], axis=1)
-        return sim_df
+        return pd.concat([t_df, y_df], axis=1)
 
+    @deprecate(
+        old="ODESimulator.run()",
+        new="ODESimulator.taufree(), .non_dim() or .dim(tau, start_date) directly")
     def run(self):
         """
-        Run the simulator.
+        From version 2.7.0, it is not necessary to perform ODESimulator.run().
+        Please directory use ODESimulator.taufree(), .non_dim() or .dim(tau, start_date)
         """
-        self._taufree_df = pd.DataFrame()
-        for setting in self.settings:
-            # Initial values
-            y0_dict = setting["y0_dict"].copy()
-            if None in y0_dict.values():
-                keys_with_none = [k for (k, v) in y0_dict.items() if v is None]
-                if keys_with_none and self._taufree_df.empty:
-                    raise NameError(
-                        "Initial values of simulation must be specified in advance."
-                    )
-                last_value_dict = {
-                    k: self._taufree_df.loc[self._taufree_df.index[-1], k]
-                    for k in keys_with_none
-                }
-                y0_dict.update(last_value_dict)
-            setting["y0_dict"] = y0_dict.copy()
-            # Solve ODEs
-            new_df = self._solve_ode(**setting)
-            taufree_df = pd.concat(
-                [self._taufree_df.iloc[:-1, :], new_df],
-                axis=0, ignore_index=True, sort=True
-            )
-            taufree_df = taufree_df.fillna(0)
-            taufree_df[self.TS] = taufree_df.index
-            self._taufree_df = taufree_df.copy()
-        return self
+        return self.taufree()
 
     def taufree(self):
         """
@@ -196,11 +178,9 @@ class ODESimulator(Term):
                     - t (int): Elapsed time divided by tau value [-]
                     - columns with dimensionalized variables
         """
-        df = self._taufree_df.copy()
-        if df.empty:
-            raise Exception("ODESimulator.run() must be done in advance.")
-        df = df.reset_index(drop=True)
-        return df
+        df = self._solve_ode(**self.setting)
+        df[self.TS] = df.index
+        return df.reset_index(drop=True)
 
     def non_dim(self):
         """
@@ -241,8 +221,7 @@ class ODESimulator(Term):
                     - variables of the models (int)
         """
         df = self.taufree()
-        df = df.drop(self.TS, axis=1)
-        df = df.reset_index(drop=True)
+        df = df.drop(self.TS, axis=1).reset_index(drop=True)
         var_cols = df.columns.tolist()
         df = df.astype(np.int64)
         # Date
