@@ -32,4 +32,4 @@ class StopWatch(object):
             (str): eg. '1 min 30 sec'
         """
         minutes, seconds = divmod(int(self.elapsed), 60)
-        return f"{minutes} min {seconds} sec"
+        return f"{minutes} min {seconds:>2} sec"
